@@ -3,8 +3,8 @@ from typing import Any, Callable
 from click import Command, Context, Group
 from sentry_sdk.api import push_scope
 
+from ..saml_clients.chooser import choose_saml_client
 from . import segment
-from .validations import validate_resource
 
 
 class AutoTagCommand(Command):
@@ -31,7 +31,12 @@ class AutoTagCommand(Command):
             self.params
             and (resource := ctx.parent.params.get("resource"))
             and self.params[0].name == "resource"
-            and (not args or not validate_resource(args[0]))
+            and (
+                not args
+                or not choose_saml_client(
+                    ctx.parent.params["saml_client_name"]
+                ).validate_resource(args[0])
+            )
         ):
             args = [resource] + args
         return super().parse_args(ctx, args)
